package Gtk2::TreeIter;

# $Id: TreeIter.pm,v 1.9 2002/12/16 17:23:12 ggc Exp $
# Copyright 2002, Gran Thyni, kirra.net
# licensed with Lesser General Public License (LGPL)
# see http://www.fsf.org/licenses/lgpl.txt

our $rcsid = '$Id: TreeIter.pm,v 1.9 2002/12/16 17:23:12 ggc Exp $';
our $VERSION = $1 if $rcsid =~ /(\d+\.[\d\.]+)/;

BEGIN { do 'Gtk2/_config.pm'; $@ and die }

1;


